package com.bgy.sms.channel.api;

import com.alibaba.fastjson.JSONObject;
import com.bgy.sms.channel.dto.*;
import com.bgy.sms.config.ResponseCode;
import com.bgy.sms.service.MessageService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@SuppressWarnings("Duplicates")
@RestController
@RequestMapping()
public class DmHubApi {

    private static final Logger log = LoggerFactory.getLogger(DmHubApi.class);

    @Autowired
    private MessageService messageService;

    /**
     * 创建短信模板
     *
     * @return
     */
    @PostMapping("/sms/template")
    public DmHubResponse template(@RequestBody DmHubTemplateRequest params) {
        log.info("**********创建模板接口入参*******：{}", JSONObject.toJSONString(params));
        DmHubResponse response;
        try {
            response = messageService.createTemplate(params);
        } catch (Exception e) {
            log.error("创建模板短信异常", e);
            response = new DmHubResponse("999", "创建模板短信异常");
        }
        log.info("**********创建模板接口出参*******：{}", JSONObject.toJSONString(response));
        return response;
    }

    /**
     * 发送短信验证码
     *
     * @return
     */
    @PostMapping("/sms/verifyCode")
    public DmHubResponse verifyCode(@RequestBody DmHubCodeRequest params) {
        log.info("**********发送短信验证码*******：{}", JSONObject.toJSONString(params));
        DmHubResponse response;
        try {
            response = messageService.sendCode(params);
        } catch (Exception e) {
            log.error("发送验证码短信异常", e);
            response = new DmHubResponse("999", "发送验证码短信异常");
        }
        log.info("**********发送短信验证码出参*******：{}", JSONObject.toJSONString(response));
        return response;
    }


    /**
     * 批量发送（通知或营销类）
     *
     * @return
     */
    @PostMapping("/sms/batch")
    public DmHubResponse batch(@RequestBody DmHubBatchSendRequest request) {
        log.info("**********批量发送入参*******：{}", JSONObject.toJSONString(request));
        DmHubResponse response;
        try {
            response = messageService.batchSendOneByOne(request);
        } catch (Exception e) {
            log.error("发送批量短信异常", e);
            response = new DmHubResponse(ResponseCode.SYSTEM_ERROR);
        }
        log.info("**********批量发送出参*******：{}", JSONObject.toJSONString(response));
        return response;
    }

    /**
     * 发送单条（通知或营销类）
     *
     * @return
     */
    @RequestMapping("/sms/send")
    public DmHubResponse send(@RequestBody DmHubSendRequest request) {
        log.info("**********单条发送入参*******：{}", JSONObject.toJSONString(request));
        DmHubResponse response;
        try {
            response = messageService.send(request);
        } catch (Exception e) {
            log.error("发送单条短信异常", e);
            response = new DmHubResponse(ResponseCode.SYSTEM_ERROR);
        }
        log.info("**********单条发送出参*******：{}", JSONObject.toJSONString(response));
        return response;
    }
}
